@@ -27,35 +27,30 @@ __all__ = (
 
 
 class EEMeterError(Exception):
-    """ Base class for EEmeter library errors.
-    """
+    """Base class for EEmeter library errors."""
 
     pass
 
 
 class NoBaselineDataError(EEMeterError):
-    """ Error indicating lack of baseline data.
-    """
+    """Error indicating lack of baseline data."""
 
     pass
 
 
 class NoReportingDataError(EEMeterError):
-    """ Error indicating lack of reporting data.
-    """
+    """Error indicating lack of reporting data."""
 
     pass
 
 
 class MissingModelParameterError(EEMeterError):
-    """ Error indicating missing model parameter.
-    """
+    """Error indicating missing model parameter."""
 
     pass
 
 
 class UnrecognizedModelTypeError(EEMeterError):
-    """ Error indicating unrecognized model type.
-    """
+    """Error indicating unrecognized model type."""
 
     pass
